#
# spec file for package jackson-annotations
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jackson-annotations
Version:        2.17.1
Release:        1.1
Summary:        Core annotations for Jackson data processor
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/FasterXML/jackson-annotations/
Source0:        https://github.com/FasterXML/jackson-annotations/archive/%{name}-%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
Core annotations used for value types,
used by Jackson data-binding package.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
cp %{SOURCE1} build.xml
mkdir -p lib

%pom_remove_plugin "org.moditect:moditect-maven-plugin"
%pom_remove_plugin "org.sonatype.plugins:nexus-staging-maven-plugin"

sed -i 's/\r//' LICENSE

%build
%{ant} -Dtest.skip=true package javadoc

%install
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

install -dm 0755 %{buildroot}%{_javadocdir}
cp -r target/site/apidocs %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md release-notes/*
%license LICENSE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE

%changelog
* Mon May 20 2024 Gus Kenion <gus.kenion@suse.com>
- Update to 2.17.1
  * No changes since 2.17.0
- Includes changes from 2.17.0
  * #242: Allow `@JsonAnySetter` on `ElementType.PARAMETER` (for
    use on constructor parameters)
* Fri Mar  8 2024 Gus Kenion <gkenion@suse.com>
- Update to 2.16.1
  * no substantial changes from 2.16.0
  * 2.16.0 (15-Nov-2023)
    + #223: Add new OptBoolean valued property in @JsonTypeInfo to
    allow per-type configuration of strict type id handling
    + #229: Add JsonTypeInfo.Value object (backport from 3.0)
    + #234: Add new JsonTypeInfo.Id.SIMPLE_NAME
* Mon Aug 21 2023 Fridrich Strba <fstrba@suse.com>
- Update to 2.15.2
  * no subsantial changes from 2.15.0
  * 2.15.0 (23-Apr-2023)
    + #211: Add 'JsonFormat.Feature's:
    READ_UNKNOWN_ENUM_VALUES_AS_NULL,
    READ_UNKNOWN_ENUM_VALUES_USING_DEFAULT_VALUE
    + #214: Add NOTICE file with copyright information
    + #221: Add
    'JsonFormat.Feature.READ_DATE_TIMESTAMPS_AS_NANOSECONDS'
  * 2.14.0 (05-Nov-2022)
    + #204: Allow explicit 'JsonSubTypes' repeated names check
* Wed Jun 15 2022 Fridrich Strba <fstrba@suse.com>
- Update to 2.13.3
  * no substantial changes, just version allignment to other
    jackson packages
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
* Wed Oct 20 2021 Fridrich Strba <fstrba@suse.com>
- Update to 2.13.0 (CVE-2020-36518, bsc#1197132)
  * 2.13.0 (30-Sep-2021)
    + Add 'mvnw' wrapper
  * 2.12.0 (29-Nov-2020)
    + #171: 'JsonSubType.Type' should accept array of names
    + #173: Jackson version alignment with Gradle 6
    + #174: Add '@JsonIncludeProperties'
    + #175: Add '@JsonTypeInfo(use=DEDUCTION)'
    + #177: Ability to use '@JsonAnyGetter' on fields
    + #179: Add '@JsonKey' annotation
    + #180: Allow repeated calls to
    'SimpleObjectIdResolver.bindItem()' for same mapping
    + #181: Add 'namespace' property for '@JsonProperty' (for
    XML module)
    + Add target 'ElementType.ANNOTATION_TYPE' for
    '@JsonEnumDefaultValue' (was missing for some reason)
  * 2.11.0 (26-Apr-2020)
    + 'JsonPattern.Value.pattern' retained as "", never
    (accidentally) exposed as 'null'
* Mon Apr 26 2021 Fridrich Strba <fstrba@suse.com>
- Rewrite to use ant for building in order to be able to use it
  in packages that have to be built before maven
* Mon Jan 25 2021 Fridrich Strba <fstrba@suse.com>
- Update to 2.10.5
* Thu Mar 26 2020 Fridrich Strba <fstrba@suse.com>
- Update to 2.10.3
* Tue Jan  7 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to 2.10.2
* Wed Nov 20 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to 2.10.1
  * 2.10.0 (26-Sep-2019)
    [#138]: Add basic Java 9+ module info
    [#141]: Add 'JsonFormat.Feature.ACCEPT_CASE_INSENSITIVE_PROPERTIES'
    [#159]: Add 'JsonFormat.Shape.BINARY'
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Add missing Group: line for javadoc subpackage.
* Wed May  8 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jackson-annotations 2.9.4
